Retrieve a data object stored in a video file metadata tag
Examples
if (FALSE) { # \dontrun{
if (interactive()) {
## mark the geometry of the court in the video
ref <- ov_shiny_court_ref(video_file = ov_example_video(), t = 5)
## store it
newfile <- ov_set_video_data(ov_example_video(), obj = ref)
## retrieve it
ov_get_video_data(newfile)
}
} # }